from setuptools import setup, find_packages


setup(
    name='Usero',
    version='0.6',
    license='MIT',
    author="Suomimuumi",
    author_email='suomimuumi69@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/suomimuumi/usero',
    keywords='usermanagement user database',
    install_requires=[
        ''
      ],

)
